"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var PLUGIN = 'CoreCSSModulesWebpackPlugin';
var isLoader = function (loader) { return loader !== 'string'; };
var CoreCSSWebpackPlugin = /** @class */ (function () {
    function CoreCSSWebpackPlugin(_a) {
        var _b = _a.suffix, suffix = _b === void 0 ? 'suffix' : _b;
        this.isDev = false;
        this.suffix = '';
        this.isDev = process.env.NODE_ENV === 'development';
        this.suffix = new Buffer(suffix || '').toString('base64').slice(0, 5);
    }
    CoreCSSWebpackPlugin.prototype.apply = function (compiler) {
        var _this = this;
        compiler.hooks.compilation.tap(PLUGIN, function (compilation) {
            compilation.hooks.buildModule.tap(PLUGIN, function (module) {
                if (module.resource && module.resource.indexOf('/core-css/') >= 0) {
                    // we need to find the css loader in the list of loaders for each module
                    module.loaders &&
                        module.loaders.filter(isLoader).forEach(function (loader) {
                            if (loader.loader.indexOf('/css-loader/') >= 0) {
                                // use existing options or default to empty object
                                loader.options = loader.options || {};
                                // turn css-modules on
                                loader.options.modules = true;
                                if (loader.options.getLocalIdent &&
                                    loader.options.getLocalIdent.name !== 'customGetLocalIdent') {
                                    // if css-loader is configured to use `getLocalIdentName` then we
                                    // want to wrap the original function and prepend it's return value
                                    var getLocalIdent_1 = loader.options.getLocalIdent;
                                    var customGetLocalIdent = function () {
                                        var args = [];
                                        for (var _i = 0; _i < arguments.length; _i++) {
                                            args[_i] = arguments[_i];
                                        }
                                        return getLocalIdent_1.apply(void 0, args) + "-" + _this.suffix;
                                    };
                                    loader.options.getLocalIdent = customGetLocalIdent;
                                }
                                else if (loader.options.localIdentName) {
                                    // if css-loader is configured to use `localIdentName`, then we
                                    // want to prepend the value to the suffix
                                    loader.options.localIdentName = loader.options.localIdentName + "-" + _this.suffix;
                                }
                                else {
                                    // css-loader is not configured to do any custom transform
                                    // of classnames, set it up while accounting for dev/prod mode
                                    loader.options.localIdentName = _this.isDev
                                        ? "[local]-[hash:base64:5]-" + _this.suffix
                                        : "[hash:base64:5]-" + _this.suffix;
                                }
                            }
                        });
                }
            });
        });
    };
    return CoreCSSWebpackPlugin;
}());
exports.CoreCSSWebpackPlugin = CoreCSSWebpackPlugin;
